// Label3D
#ifndef __LABEL3D__HH_
#define __LABEL3D__HH_
#include <Performer/pf/pfDCS.h>
#include <Performer/pf/pfText.h>
#include <Performer/pr/pfLinMath.h>
#include <Performer/pf/pfSCS.h>
#include <Performer/pfdu.h>
#include <Performer/pr/pfString.h>
#include <Performer/pr/pfFont.h>

enum LabelJustification {Left=PFSTR_LEFT,Right=PFSTR_RIGHT,Center=PFSTR_CENTER};
enum FontStyle {Filled=PFDFONT_FILLED,Extruded=PFDFONT_EXTRUDED, // Extruded works but is slow
		Outline=PFDFONT_OUTLINED,Outlined=PFDFONT_OUTLINED,// Fast but faint
		Vector=PFDFONT_VECTOR,Textured=PFDFONT_TEXTURED}; // 3D?... never worked...
class Label3D {
  pfString *string;
  pfFont *font;
  pfText *text;
public:
  Label3D(pfGroup *parent);
  ~Label3D();
  void setLabel(char *label); // Set the text for the 3D label
  inline void optimize(){ string->flatten();} // flattens the geometry for faster drawing
  inline void setMat(pfMatrix &mat){ string->setMat(mat);} // set transform mat
  inline void getMat(pfMatrix &mat){ string->getMat(mat);} // get the curren matrix trans
  void setTrans(float x,float y,float z); // Translate the text in x,y or z direction
  // Rotate the text in x,y, or z axes by 'deg' degrees. x,y, and z must be a 
  // unit vector defining the axis of rotation
  void setRot(float deg,float x,float y,float z);
  // setcolor (red,green,blue) and transparency.  If you leave out the transparency,
  // then the default is opaque (a=1.0).  All values range from 0.0 to 1.0.
  inline void setColor(float r,float g,float b,float a=1.0){
    string->setColor(r,g,b,a);
  }
  // Same as above, but using a pfVec4 (standard in performer for colors)
  inline void setColor(pfVec4 &color){
    string->setColor(color.vec[0],
		     color.vec[1],
		     color.vec[2],
		     color.vec[3]);
  }
  // Justify the text left,right or centered w/respect to the position
  // of the label (default is right-justified)
  inline void justify(LabelJustification j){string->setMode(PFSTR_JUSTIFY,j);}
  // Get the width and height of the label.
  void getSize(float &width,float &height); // assume 2D model for now
  // Set the maximum width and height of the label. This causes the
  // label to be scaled automatically to fit within this bouding box.
  void setSize(float width,float height);
  // Only two fonts to choose from.  Don't even bother..
  void setFont(char *fontname,FontStyle style=Filled);
  // In the cave, the fontsize is height in feet.
  void setFontSize(float height);
};

#endif // __LABEL3D_HH_

